# ----------------------------------------------------------------------------
#
#  Welcome to Baml! To use this generated code, please run the following:
#
#  $ pip install baml
#
# ----------------------------------------------------------------------------

# This file was generated by BAML: please do not edit it. Instead, edit the
# BAML files and re-generate this code using: baml-cli generate
# baml-cli is available with the baml package.

from . import types
from . import stream_types


type_map = {

    "types.AICommandHistoryItem": types.AICommandHistoryItem,
    "stream_types.AICommandHistoryItem": stream_types.AICommandHistoryItem,

    "types.AICommandRequest": types.AICommandRequest,
    "stream_types.AICommandRequest": stream_types.AICommandRequest,

    "types.AICommandResult": types.AICommandResult,
    "stream_types.AICommandResult": stream_types.AICommandResult,

    "types.ActionError": types.ActionError,
    "stream_types.ActionError": stream_types.ActionError,

    "types.ActionEventPayload": types.ActionEventPayload,
    "stream_types.ActionEventPayload": stream_types.ActionEventPayload,

    "types.ActionOutput": types.ActionOutput,
    "stream_types.ActionOutput": stream_types.ActionOutput,

    "types.ActionRequest": types.ActionRequest,
    "stream_types.ActionRequest": stream_types.ActionRequest,

    "types.ActionResponse": types.ActionResponse,
    "stream_types.ActionResponse": stream_types.ActionResponse,

    "types.AiTimingSuggestion": types.AiTimingSuggestion,
    "stream_types.AiTimingSuggestion": stream_types.AiTimingSuggestion,

    "types.AiTimingSuggestionRequest": types.AiTimingSuggestionRequest,
    "stream_types.AiTimingSuggestionRequest": stream_types.AiTimingSuggestionRequest,

    "types.AuthVerifyResponse": types.AuthVerifyResponse,
    "stream_types.AuthVerifyResponse": stream_types.AuthVerifyResponse,

    "types.ChatMessage": types.ChatMessage,
    "stream_types.ChatMessage": stream_types.ChatMessage,

    "types.ChatRequest": types.ChatRequest,
    "stream_types.ChatRequest": stream_types.ChatRequest,

    "types.ChatResponse": types.ChatResponse,
    "stream_types.ChatResponse": stream_types.ChatResponse,

    "types.ClientContext": types.ClientContext,
    "stream_types.ClientContext": stream_types.ClientContext,

    "types.CommandCenterData": types.CommandCenterData,
    "stream_types.CommandCenterData": stream_types.CommandCenterData,

    "types.CommandCenterEventPayload": types.CommandCenterEventPayload,
    "stream_types.CommandCenterEventPayload": stream_types.CommandCenterEventPayload,

    "types.CommandCenterItem": types.CommandCenterItem,
    "stream_types.CommandCenterItem": stream_types.CommandCenterItem,

    "types.ConnectionPayload": types.ConnectionPayload,
    "stream_types.ConnectionPayload": stream_types.ConnectionPayload,

    "types.ContextChangedPayload": types.ContextChangedPayload,
    "stream_types.ContextChangedPayload": stream_types.ContextChangedPayload,

    "types.CreateResourceRequest": types.CreateResourceRequest,
    "stream_types.CreateResourceRequest": stream_types.CreateResourceRequest,

    "types.CreateScheduledMessageRequest": types.CreateScheduledMessageRequest,
    "stream_types.CreateScheduledMessageRequest": stream_types.CreateScheduledMessageRequest,

    "types.CurrentRead": types.CurrentRead,
    "stream_types.CurrentRead": stream_types.CurrentRead,

    "types.ErrorPayload": types.ErrorPayload,
    "stream_types.ErrorPayload": stream_types.ErrorPayload,

    "types.EventEnvelope": types.EventEnvelope,
    "stream_types.EventEnvelope": stream_types.EventEnvelope,

    "types.EventMeta": types.EventMeta,
    "stream_types.EventMeta": stream_types.EventMeta,

    "types.FrontendActionResult": types.FrontendActionResult,
    "stream_types.FrontendActionResult": stream_types.FrontendActionResult,

    "types.FrontendCommand": types.FrontendCommand,
    "stream_types.FrontendCommand": stream_types.FrontendCommand,

    "types.FrontendCommandPayload": types.FrontendCommandPayload,
    "stream_types.FrontendCommandPayload": stream_types.FrontendCommandPayload,

    "types.FrontendToolConfig": types.FrontendToolConfig,
    "stream_types.FrontendToolConfig": stream_types.FrontendToolConfig,

    "types.HeartbeatPayload": types.HeartbeatPayload,
    "stream_types.HeartbeatPayload": stream_types.HeartbeatPayload,

    "types.IntegrationConfig": types.IntegrationConfig,
    "stream_types.IntegrationConfig": stream_types.IntegrationConfig,

    "types.IntegrationConnectRequest": types.IntegrationConnectRequest,
    "stream_types.IntegrationConnectRequest": stream_types.IntegrationConnectRequest,

    "types.IntegrationConnectResponse": types.IntegrationConnectResponse,
    "stream_types.IntegrationConnectResponse": stream_types.IntegrationConnectResponse,

    "types.IntegrationDisconnectRequest": types.IntegrationDisconnectRequest,
    "stream_types.IntegrationDisconnectRequest": stream_types.IntegrationDisconnectRequest,

    "types.IntegrationList": types.IntegrationList,
    "stream_types.IntegrationList": stream_types.IntegrationList,

    "types.MessagePayload": types.MessagePayload,
    "stream_types.MessagePayload": stream_types.MessagePayload,

    "types.NavigationOption": types.NavigationOption,
    "stream_types.NavigationOption": stream_types.NavigationOption,

    "types.ObservationEntry": types.ObservationEntry,
    "stream_types.ObservationEntry": stream_types.ObservationEntry,

    "types.ObservationPayload": types.ObservationPayload,
    "stream_types.ObservationPayload": stream_types.ObservationPayload,

    "types.OnboardingEventPayload": types.OnboardingEventPayload,
    "stream_types.OnboardingEventPayload": stream_types.OnboardingEventPayload,

    "types.OnboardingPhaseProgress": types.OnboardingPhaseProgress,
    "stream_types.OnboardingPhaseProgress": stream_types.OnboardingPhaseProgress,

    "types.OnboardingProgress": types.OnboardingProgress,
    "stream_types.OnboardingProgress": stream_types.OnboardingProgress,

    "types.OnboardingUpdateRequest": types.OnboardingUpdateRequest,
    "stream_types.OnboardingUpdateRequest": stream_types.OnboardingUpdateRequest,

    "types.OnboardingUpdateResponse": types.OnboardingUpdateResponse,
    "stream_types.OnboardingUpdateResponse": stream_types.OnboardingUpdateResponse,

    "types.PageContext": types.PageContext,
    "stream_types.PageContext": stream_types.PageContext,

    "types.PriorityItemPayload": types.PriorityItemPayload,
    "stream_types.PriorityItemPayload": stream_types.PriorityItemPayload,

    "types.PrivateIntelligence": types.PrivateIntelligence,
    "stream_types.PrivateIntelligence": stream_types.PrivateIntelligence,

    "types.ProfileScrapeRequest": types.ProfileScrapeRequest,
    "stream_types.ProfileScrapeRequest": stream_types.ProfileScrapeRequest,

    "types.ProfileScrapeResponse": types.ProfileScrapeResponse,
    "stream_types.ProfileScrapeResponse": stream_types.ProfileScrapeResponse,

    "types.ResolvedContext": types.ResolvedContext,
    "stream_types.ResolvedContext": stream_types.ResolvedContext,

    "types.ResourceEventPayload": types.ResourceEventPayload,
    "stream_types.ResourceEventPayload": stream_types.ResourceEventPayload,

    "types.ResourceItem": types.ResourceItem,
    "stream_types.ResourceItem": stream_types.ResourceItem,

    "types.ResourceListData": types.ResourceListData,
    "stream_types.ResourceListData": stream_types.ResourceListData,

    "types.ResourceMetadata": types.ResourceMetadata,
    "stream_types.ResourceMetadata": stream_types.ResourceMetadata,

    "types.ScheduledMessage": types.ScheduledMessage,
    "stream_types.ScheduledMessage": stream_types.ScheduledMessage,

    "types.ScheduledMessageAuditEntry": types.ScheduledMessageAuditEntry,
    "stream_types.ScheduledMessageAuditEntry": stream_types.ScheduledMessageAuditEntry,

    "types.ScheduledMessageEventPayload": types.ScheduledMessageEventPayload,
    "stream_types.ScheduledMessageEventPayload": stream_types.ScheduledMessageEventPayload,

    "types.ScheduledMessageFilter": types.ScheduledMessageFilter,
    "stream_types.ScheduledMessageFilter": stream_types.ScheduledMessageFilter,

    "types.ScheduledMessageList": types.ScheduledMessageList,
    "stream_types.ScheduledMessageList": stream_types.ScheduledMessageList,

    "types.ScheduledMessagePreferences": types.ScheduledMessagePreferences,
    "stream_types.ScheduledMessagePreferences": stream_types.ScheduledMessagePreferences,

    "types.ScrapedCoachProfile": types.ScrapedCoachProfile,
    "stream_types.ScrapedCoachProfile": stream_types.ScrapedCoachProfile,

    "types.SessionContext": types.SessionContext,
    "stream_types.SessionContext": stream_types.SessionContext,

    "types.SessionEventPayload": types.SessionEventPayload,
    "stream_types.SessionEventPayload": stream_types.SessionEventPayload,

    "types.SessionNotesDocument": types.SessionNotesDocument,
    "stream_types.SessionNotesDocument": stream_types.SessionNotesDocument,

    "types.SessionNotesEventPayload": types.SessionNotesEventPayload,
    "stream_types.SessionNotesEventPayload": stream_types.SessionNotesEventPayload,

    "types.SessionNotesFilter": types.SessionNotesFilter,
    "stream_types.SessionNotesFilter": stream_types.SessionNotesFilter,

    "types.SessionNotesFinalizeRequest": types.SessionNotesFinalizeRequest,
    "stream_types.SessionNotesFinalizeRequest": stream_types.SessionNotesFinalizeRequest,

    "types.SessionNotesFinalizeResponse": types.SessionNotesFinalizeResponse,
    "stream_types.SessionNotesFinalizeResponse": stream_types.SessionNotesFinalizeResponse,

    "types.SessionNotesList": types.SessionNotesList,
    "stream_types.SessionNotesList": stream_types.SessionNotesList,

    "types.SessionNotesRequest": types.SessionNotesRequest,
    "stream_types.SessionNotesRequest": stream_types.SessionNotesRequest,

    "types.SessionNotesResponse": types.SessionNotesResponse,
    "stream_types.SessionNotesResponse": stream_types.SessionNotesResponse,

    "types.SessionNotesSummary": types.SessionNotesSummary,
    "stream_types.SessionNotesSummary": stream_types.SessionNotesSummary,

    "types.SessionSectionContent": types.SessionSectionContent,
    "stream_types.SessionSectionContent": stream_types.SessionSectionContent,

    "types.SessionSectionUpdateRequest": types.SessionSectionUpdateRequest,
    "stream_types.SessionSectionUpdateRequest": stream_types.SessionSectionUpdateRequest,

    "types.SessionSectionUpdateResponse": types.SessionSectionUpdateResponse,
    "stream_types.SessionSectionUpdateResponse": stream_types.SessionSectionUpdateResponse,

    "types.StateHistoryEntry": types.StateHistoryEntry,
    "stream_types.StateHistoryEntry": stream_types.StateHistoryEntry,

    "types.StateHistoryQuery": types.StateHistoryQuery,
    "stream_types.StateHistoryQuery": stream_types.StateHistoryQuery,

    "types.StateUpdateRequest": types.StateUpdateRequest,
    "stream_types.StateUpdateRequest": stream_types.StateUpdateRequest,

    "types.StateUpdateResponse": types.StateUpdateResponse,
    "stream_types.StateUpdateResponse": stream_types.StateUpdateResponse,

    "types.SuggestedAction": types.SuggestedAction,
    "stream_types.SuggestedAction": stream_types.SuggestedAction,

    "types.T15PrepDocument": types.T15PrepDocument,
    "stream_types.T15PrepDocument": stream_types.T15PrepDocument,

    "types.T15PrepEventPayload": types.T15PrepEventPayload,
    "stream_types.T15PrepEventPayload": stream_types.T15PrepEventPayload,

    "types.T15PrepList": types.T15PrepList,
    "stream_types.T15PrepList": stream_types.T15PrepList,

    "types.T15PrepRequest": types.T15PrepRequest,
    "stream_types.T15PrepRequest": stream_types.T15PrepRequest,

    "types.T15PrepResponse": types.T15PrepResponse,
    "stream_types.T15PrepResponse": stream_types.T15PrepResponse,

    "types.T15PrepSummary": types.T15PrepSummary,
    "stream_types.T15PrepSummary": stream_types.T15PrepSummary,

    "types.T15SectionContent": types.T15SectionContent,
    "stream_types.T15SectionContent": stream_types.T15SectionContent,

    "types.T15SectionUpdateRequest": types.T15SectionUpdateRequest,
    "stream_types.T15SectionUpdateRequest": stream_types.T15SectionUpdateRequest,

    "types.T15SectionUpdateResponse": types.T15SectionUpdateResponse,
    "stream_types.T15SectionUpdateResponse": stream_types.T15SectionUpdateResponse,

    "types.TonePreference": types.TonePreference,
    "stream_types.TonePreference": stream_types.TonePreference,

    "types.ToolDefinition": types.ToolDefinition,
    "stream_types.ToolDefinition": stream_types.ToolDefinition,

    "types.ToolParameter": types.ToolParameter,
    "stream_types.ToolParameter": stream_types.ToolParameter,

    "types.TransparentMessage": types.TransparentMessage,
    "stream_types.TransparentMessage": stream_types.TransparentMessage,

    "types.UpdatePreferencesRequest": types.UpdatePreferencesRequest,
    "stream_types.UpdatePreferencesRequest": stream_types.UpdatePreferencesRequest,

    "types.UpdateResourceRequest": types.UpdateResourceRequest,
    "stream_types.UpdateResourceRequest": stream_types.UpdateResourceRequest,

    "types.UpdateScheduledMessageRequest": types.UpdateScheduledMessageRequest,
    "stream_types.UpdateScheduledMessageRequest": stream_types.UpdateScheduledMessageRequest,

    "types.UserActiveState": types.UserActiveState,
    "stream_types.UserActiveState": stream_types.UserActiveState,

    "types.VoiceCorrection": types.VoiceCorrection,
    "stream_types.VoiceCorrection": stream_types.VoiceCorrection,

    "types.VoiceCorrectionRequest": types.VoiceCorrectionRequest,
    "stream_types.VoiceCorrectionRequest": stream_types.VoiceCorrectionRequest,

    "types.VoiceCorrectionResponse": types.VoiceCorrectionResponse,
    "stream_types.VoiceCorrectionResponse": stream_types.VoiceCorrectionResponse,

    "types.VoiceEventPayload": types.VoiceEventPayload,
    "stream_types.VoiceEventPayload": stream_types.VoiceEventPayload,

    "types.VoiceProfile": types.VoiceProfile,
    "stream_types.VoiceProfile": stream_types.VoiceProfile,

    "types.VoiceProfileConfig": types.VoiceProfileConfig,
    "stream_types.VoiceProfileConfig": stream_types.VoiceProfileConfig,

    "types.VoiceSample": types.VoiceSample,
    "stream_types.VoiceSample": stream_types.VoiceSample,

    "types.VoiceSampleInput": types.VoiceSampleInput,
    "stream_types.VoiceSampleInput": stream_types.VoiceSampleInput,

    "types.VoiceSampleSubmitRequest": types.VoiceSampleSubmitRequest,
    "stream_types.VoiceSampleSubmitRequest": stream_types.VoiceSampleSubmitRequest,

    "types.VoiceSampleSubmitResponse": types.VoiceSampleSubmitResponse,
    "stream_types.VoiceSampleSubmitResponse": stream_types.VoiceSampleSubmitResponse,

    "types.VoiceSamplesPayload": types.VoiceSamplesPayload,
    "stream_types.VoiceSamplesPayload": stream_types.VoiceSamplesPayload,


    "types.AICommandType": types.AICommandType,

    "types.CoachFeedback": types.CoachFeedback,

    "types.CommandItemType": types.CommandItemType,

    "types.EditType": types.EditType,

    "types.EventType": types.EventType,

    "types.FrontendActionStatus": types.FrontendActionStatus,

    "types.FrontendToolName": types.FrontendToolName,

    "types.IntegrationStatus": types.IntegrationStatus,

    "types.IntegrationType": types.IntegrationType,

    "types.MessageChannel": types.MessageChannel,

    "types.MessageRole": types.MessageRole,

    "types.MessageStatus": types.MessageStatus,

    "types.ObservationType": types.ObservationType,

    "types.OnboardingAction": types.OnboardingAction,

    "types.OnboardingPhase": types.OnboardingPhase,

    "types.PhaseStatus": types.PhaseStatus,

    "types.Priority": types.Priority,

    "types.ResourceType": types.ResourceType,

    "types.SessionNoteSection": types.SessionNoteSection,

    "types.SessionNotesStatus": types.SessionNotesStatus,

    "types.StateSource": types.StateSource,

    "types.T15PrepSection": types.T15PrepSection,

    "types.ToolName": types.ToolName,

    "types.TransparencyIndicator": types.TransparencyIndicator,

    "types.VoiceContentType": types.VoiceContentType,

    "types.VoiceSampleStatus": types.VoiceSampleStatus,

    "types.VoiceSampleType": types.VoiceSampleType,

    "types.VoiceTrainingStatus": types.VoiceTrainingStatus,

}